0.2
---
-  Refactored `elixr` into a namespace package with existing code moved into 
   the core package, thus the package effectively became `elixr.core`.

0.1
---
-  Defined AttrDict and extension hook for the import mechanism

0.0
---
-  Initial version